/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
/*
 * xesam-glib
 * Copyright (C) Mikkel Kamstrup Erlandsen 2008 <mikkel.kamstrup@gmail.com>
 * 
 * xesam-glib is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * xesam-glib is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with xesam-glib.  If not, write to:
 * 	The Free Software Foundation, Inc.,
 * 	51 Franklin Street, Fifth Floor
 * 	Boston, MA  02110-1301, USA.
 */

#ifndef __XESAM_G_QUERY_BUILDER_H__
#define __XESAM_G_QUERY_BUILDER_H__

#include <glib.h>
#include <glib-object.h>
#include <xesam-glib/xesam-g-query-token.h>

G_BEGIN_DECLS

#define XESAM_TYPE_G_QUERY_BUILDER (xesam_g_query_builder_get_type ())
#define XESAM_G_QUERY_BUILDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XESAM_TYPE_G_QUERY_BUILDER, XesamGQueryBuilder))
#define XESAM_IS_G_QUERY_BUILDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XESAM_TYPE_G_QUERY_BUILDER))
#define XESAM_G_QUERY_BUILDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), XESAM_TYPE_G_QUERY_BUILDER, XesamGQueryBuilderIface))

typedef struct _XesamGQueryBuilder XesamGQueryBuilder;
typedef struct _XesamGQueryBuilderIface XesamGQueryBuilderIface;

typedef enum  {
	XESAM_G_QUERY_BUILDER_ERROR_UNKNOWN_FIELD,
	XESAM_G_QUERY_BUILDER_ERROR_INVALID_CLAUSE_ATTRIBUTE,
	XESAM_G_QUERY_BUILDER_ERROR_INVALID_ATTRIBUTE_LIST,
	XESAM_G_QUERY_BUILDER_ERROR_NO_CHILD
} XesamGQueryBuilderError;

struct _XesamGQueryBuilderIface {
	GTypeInterface		parent_iface;
	
	gboolean			(*start_query) 				(XesamGQueryBuilder		*self,
													 XesamGQueryToken		token,
													 const gchar			*content_cat,
													 const gchar			*source_cat,
													 GError					**error);
	
	gboolean			(*add_clause)				(XesamGQueryBuilder		*self,
													 XesamGQueryToken		token,
													 const gchar			*boost,
													 const gboolean			*negate,
													 const gchar			**attr_names,
													 const gchar			**attr_vals,
													 GError** error);
	
	gboolean			(*add_field)				(XesamGQueryBuilder		*self,
													 XesamGQueryToken		token,
													 const char				*name,
													 GError					**error);
	
	gboolean			(*add_value)				(XesamGQueryBuilder		*self,
													 XesamGQueryToken		token,
													 const gchar			*value,
													 const gchar			**attr_names,
													 const gchar			**attr_vals,
													 GError					**error);
	
	gboolean			(*close_clause)				(XesamGQueryBuilder		*self,
													 GError					**error);
	
	gboolean			(*close_query)				(XesamGQueryBuilder		*self,
													 GError					**error);
};

GType					xesam_g_query_builder_get_type			(void);

GQuark					xesam_g_query_builder_error_quark		(void);

#define XESAM_G_QUERY_BUILDER_ERROR xesam_g_query_builder_error_quark ()

gboolean				xesam_g_query_builder_start_query		(XesamGQueryBuilder	*self,
																 XesamGQueryToken	token,
																 const gchar		*content_cat,
																 const gchar		*source_cat,
																 GError				**error);

gboolean				xesam_g_query_builder_add_clause		(XesamGQueryBuilder	*self,
																 XesamGQueryToken	token,
																 const gchar		*boost,
																 const gboolean		*negate,
																 const gchar		**attr_names,
																 const gchar		**attr_vals,
																 GError				**error);

gboolean				xesam_g_query_builder_add_field			(XesamGQueryBuilder	*self,
																 XesamGQueryToken	token,
																 const char			*name,
																 GError				**error);

gboolean				xesam_g_query_builder_add_value			(XesamGQueryBuilder	*self,
																 XesamGQueryToken	token,
																 const gchar		*value,
																 const gchar		**attr_names,
																 const gchar		**attr_vals,
																 GError				**error);

gboolean				xesam_g_query_builder_close_clause		(XesamGQueryBuilder	*self,
																 GError				**error);

gboolean				xesam_g_query_builder_close_query
																(XesamGQueryBuilder	*self,
																 GError				**error);

G_END_DECLS

#endif
