/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
/*
 * xesam-glib
 * Copyright (C) Mikkel Kamstrup Erlandsen 2008 <mikkel.kamstrup@gmail.com>
 * 
 * xesam-glib is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * xesam-glib is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with xesam-glib.  If not, write to:
 * 	The Free Software Foundation, Inc.,
 * 	51 Franklin Street, Fifth Floor
 * 	Boston, MA  02110-1301, USA.
 */

#ifndef __XESAM_G_QUERY_PARSER_H__
#define __XESAM_G_QUERY_PARSER_H__

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <xesam-glib/xesam-g-query-builder.h>

G_BEGIN_DECLS


#define XESAM_TYPE_G_QUERY_PARSER (xesam_g_query_parser_get_type ())
#define XESAM_G_QUERY_PARSER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XESAM_TYPE_G_QUERY_PARSER, XesamGQueryParser))
#define XESAM_G_QUERY_PARSER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XESAM_TYPE_G_QUERY_PARSER, XesamGQueryParserClass))
#define XESAM_IS_G_QUERY_PARSER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XESAM_TYPE_G_QUERY_PARSER))
#define XESAM_IS_G_QUERY_PARSER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XESAM_TYPE_G_QUERY_PARSER))
#define XESAM_G_QUERY_PARSER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XESAM_TYPE_G_QUERY_PARSER, XesamGQueryParserClass))

typedef struct _XesamGQueryParser XesamGQueryParser;
typedef struct _XesamGQueryParserClass XesamGQueryParserClass;
typedef struct _XesamGQueryParserPrivate XesamGQueryParserPrivate;

typedef enum  {
	XESAM_G_QUERY_PARSER_ERROR_CONCURRENT_PARSE,
	XESAM_G_QUERY_PARSER_ERROR_MALFORMED_QUERY,
	XESAM_G_QUERY_PARSER_ERROR_MISSING_REQUEST,
	XESAM_G_QUERY_PARSER_ERROR_UNKNOWN_ELEMENT
} XesamGQueryParserError;

struct _XesamGQueryParser {
	GObject						parent_instance;
	XesamGQueryParserPrivate	*priv;
};

struct _XesamGQueryParserClass {
	GObjectClass parent_class;
};

GType		xesam_g_query_parser_get_type				(void);

GQuark 		xesam_g_query_parser_error_quark			(void);

#define XESAM_G_QUERY_PARSER_ERROR xesam_g_query_parser_error_quark ()

void		xesam_g_query_parser_add_builder			(XesamGQueryParser		*self,
														 XesamGQueryBuilder		*builder);

gboolean	xesam_g_query_parser_parse_string			(XesamGQueryParser		*self,
														 const char				*query,
														 GError					**error);

XesamGQueryParser*
			xesam_g_query_parser_new					(void);


G_END_DECLS

#endif
