/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
/*
 * xesam-glib
 * Copyright (C) Mikkel Kamstrup Erlandsen 2008 <mikkel.kamstrup@gmail.com>
 * 
 * xesam-glib is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * xesam-glib is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with xesam-glib.  If not, write to:
 * 	The Free Software Foundation, Inc.,
 * 	51 Franklin Street, Fifth Floor
 * 	Boston, MA  02110-1301, USA.
 */

#ifndef __XESAM_G_QUERY_TOKEN_H__
#define __XESAM_G_QUERY_TOKEN_H__

#include <glib.h>

G_BEGIN_DECLS

/**
 * XesamGQueryToken:
 * @XESAM_G_QUERY_TOKEN_NONE: An unset or non-existing token
 * @XESAM_G_QUERY_TOKEN_REQUEST: 
 * @XESAM_G_QUERY_TOKEN_QUERY_FIRST:
 * @XESAM_G_QUERY_TOKEN_USER_QUERY:
 * @XESAM_G_QUERY_TOKEN_QUERY:
 * @XESAM_G_QUERY_TOKEN_QUERY_LAST:
 * @XESAM_G_QUERY_TOKEN_FIELD_FIRST:
 * @XESAM_G_QUERY_TOKEN_FIELD:
 * @XESAM_G_QUERY_TOKEN_FULL_TEXT_FIELDS:
 * @XESAM_G_QUERY_TOKEN_FIELD_LAST:
 * @XESAM_G_QUERY_TOKEN_VALUE_FIRST:
 * @XESAM_G_QUERY_TOKEN_STRING:
 * @XESAM_G_QUERY_TOKEN_INTEGER:
 * @XESAM_G_QUERY_TOKEN_BOOLEAN:
 * @XESAM_G_QUERY_TOKEN_FLOAT:
 * @XESAM_G_QUERY_TOKEN_DATE:
 * @XESAM_G_QUERY_TOKEN_VALUE_LAST:
 * @XESAM_G_QUERY_TOKEN_CLAUSE_FIRST:
 * @XESAM_G_QUERY_TOKEN_COLLECTOR_FIRST:
 * @XESAM_G_QUERY_TOKEN_AND:
 * @XESAM_G_QUERY_TOKEN_OR:
 * @XESAM_G_QUERY_TOKEN_COLLECTOR_LAST:
 * @XESAM_G_QUERY_TOKEN_SELECTOR_FIRST:
 * @XESAM_G_QUERY_TOKEN_EQUALS:
 * @XESAM_G_QUERY_TOKEN_CONTAINS:
 * @XESAM_G_QUERY_TOKEN_LESS_THAN:
 * @XESAM_G_QUERY_TOKEN_LESS_THAN_EQUALS:
 * @XESAM_G_QUERY_TOKEN_GREATER_THAN:
 * @XESAM_G_QUERY_TOKEN_GREATER_THAN_EQUALS:
 * @XESAM_G_QUERY_TOKEN_STARTS_WITH:
 * @XESAM_G_QUERY_TOKEN_IN_SET:
 * @XESAM_G_QUERY_TOKEN_FULL_TEXT:
 * @XESAM_G_QUERY_TOKEN_EXTENSION_FIRST:
 * @XESAM_G_QUERY_TOKEN_PROXIMITY:
 * @XESAM_G_QUERY_TOKEN_REG_EXP:
 * @XESAM_G_QUERY_TOKEN_CATEGORY,:
 * @XESAM_G_QUERY_TOKEN_EXTENSION_LAST:
 * @XESAM_G_QUERY_TOKEN_SELECTOR_LAST:
 * @XESAM_G_QUERY_TOKEN_CLAUSE_LAST:
 */
typedef enum  {
	XESAM_G_QUERY_TOKEN_NONE,
	
	XESAM_G_QUERY_TOKEN_REQUEST,
	
	/* Query token types */
	XESAM_G_QUERY_TOKEN_QUERY_FIRST,
	XESAM_G_QUERY_TOKEN_USER_QUERY,
	XESAM_G_QUERY_TOKEN_QUERY,
	XESAM_G_QUERY_TOKEN_QUERY_LAST,

	/* Field token types */
	XESAM_G_QUERY_TOKEN_FIELD_FIRST,
	XESAM_G_QUERY_TOKEN_FIELD,
	XESAM_G_QUERY_TOKEN_FULL_TEXT_FIELDS,
	XESAM_G_QUERY_TOKEN_FIELD_LAST,

	/* Value token types */
	XESAM_G_QUERY_TOKEN_VALUE_FIRST,
	XESAM_G_QUERY_TOKEN_STRING,
	XESAM_G_QUERY_TOKEN_INTEGER,
	XESAM_G_QUERY_TOKEN_BOOLEAN,
	XESAM_G_QUERY_TOKEN_FLOAT,
	XESAM_G_QUERY_TOKEN_DATE,
	XESAM_G_QUERY_TOKEN_VALUE_LAST,

	/* Collectors, Selectors,
	 * and Extensions are Clause sub-types. Everything until
	 * XESAM_G_QUERY_TOKEN_CLAUSE_LAST is considered a clause sub-type */
	XESAM_G_QUERY_TOKEN_CLAUSE_FIRST,
	
	/* Collectors (clause subtype) */
	XESAM_G_QUERY_TOKEN_COLLECTOR_FIRST,
	XESAM_G_QUERY_TOKEN_AND,
	XESAM_G_QUERY_TOKEN_OR,
	XESAM_G_QUERY_TOKEN_COLLECTOR_LAST,
	
	/* Selectors (clause subtype). All query language extensions
	 * are also selector sub-types */
	XESAM_G_QUERY_TOKEN_SELECTOR_FIRST,
	XESAM_G_QUERY_TOKEN_EQUALS,
	XESAM_G_QUERY_TOKEN_CONTAINS,
	XESAM_G_QUERY_TOKEN_LESS_THAN,
	XESAM_G_QUERY_TOKEN_LESS_THAN_EQUALS,
	XESAM_G_QUERY_TOKEN_GREATER_THAN,
	XESAM_G_QUERY_TOKEN_GREATER_THAN_EQUALS,
	XESAM_G_QUERY_TOKEN_STARTS_WITH,
	XESAM_G_QUERY_TOKEN_IN_SET,
	XESAM_G_QUERY_TOKEN_FULL_TEXT,
	
	/* Extensions. All extensions are also selectors */
	XESAM_G_QUERY_TOKEN_EXTENSION_FIRST,
	XESAM_G_QUERY_TOKEN_PROXIMITY,
	XESAM_G_QUERY_TOKEN_REG_EXP,
	XESAM_G_QUERY_TOKEN_CATEGORY,
	XESAM_G_QUERY_TOKEN_EXTENSION_LAST,
	
	/* End selector types */
	XESAM_G_QUERY_TOKEN_SELECTOR_LAST,
	
	/* End of clause subtypes */
	XESAM_G_QUERY_TOKEN_CLAUSE_LAST
	
} XesamGQueryToken;

const gchar*		xesam_g_query_token_get_name		(XesamGQueryToken	tok);

XesamGQueryToken	xesam_g_query_token_parse			(const gchar		*elt);		

gboolean			xesam_g_query_token_is_query_type	(XesamGQueryToken	tok);

gboolean			xesam_g_query_token_is_field_type	(XesamGQueryToken	tok);

gboolean			xesam_g_query_token_is_value_type	(XesamGQueryToken	tok);

gboolean			xesam_g_query_token_is_clause_type	(XesamGQueryToken	tok);

gboolean			xesam_g_query_token_is_collector_type (XesamGQueryToken	tok);

gboolean			xesam_g_query_token_is_selector_type  (XesamGQueryToken	tok);

gboolean			xesam_g_query_token_is_extension_type (XesamGQueryToken	tok);



G_END_DECLS

#endif
