/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
/*
 * xesam-glib
 * Copyright (C) Mikkel Kamstrup Erlandsen 2007 <mikkel.kamstrup@gmail.com>
 * 
 * xesam-glib is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * xesam-glib is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with xesam-glib.  If not, write to:
 * 	The Free Software Foundation, Inc.,
 * 	51 Franklin Street, Fifth Floor
 * 	Boston, MA  02110-1301, USA.
 */

#ifndef _XESAM_G_SEARCH_H_
#define _XESAM_G_SEARCH_H_

#include <glib-object.h>
#include <xesam-glib/xesam-g-hits.h>
#include <xesam-glib/xesam-g-query.h>
#include <xesam-glib/xesam-g-session.h>

G_BEGIN_DECLS

#define XESAM_TYPE_G_SEARCH             (xesam_g_search_get_type ())
#define XESAM_G_SEARCH(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), XESAM_TYPE_G_SEARCH, XesamGSearch))
#define XESAM_G_SEARCH_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), XESAM_TYPE_G_SEARCH, XesamGSearchClass))
#define XESAM_IS_G_SEARCH(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XESAM_TYPE_G_SEARCH))
#define XESAM_IS_G_SEARCH_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), XESAM_TYPE_G_SEARCH))
#define XESAM_G_SEARCH_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), XESAM_TYPE_G_SEARCH, XesamGSearchClass))

/* Public structs */
typedef struct _XesamGSearchClass XesamGSearchClass;
/* XesamGSearch is forward declared in xesam-g-session.h */

/* Private structs */
typedef struct _XesamGSearchPrivate XesamGSearchPrivate;

struct _XesamGSearchClass
{
	GObjectClass parent_class;
};

struct _XesamGSearch
{
	GObject 				parent_instance;
	XesamGSearchPrivate 	*priv;
};

/* Public methods */
GType 			xesam_g_search_get_type 			(void) G_GNUC_CONST;

gboolean		xesam_g_search_is_ready				(XesamGSearch 	*search);

void			xesam_g_search_start				(XesamGSearch 	*search);

gboolean		xesam_g_search_is_running			(XesamGSearch   *search);

void			xesam_g_search_close				(XesamGSearch 	*search);

gboolean		xesam_g_search_is_closed			(XesamGSearch 	*search);

gboolean		xesam_g_search_is_done				(XesamGSearch 	*search);

void			xesam_g_search_continue				(XesamGSearch 	*search);

guint			xesam_g_search_get_num_found		(XesamGSearch 	*search);

guint			xesam_g_search_get_num_read			(XesamGSearch 	*search);

void			xesam_g_search_get_extended_data 	(XesamGSearch 	*search,
													 guint 			*hit_ids);

XesamGSession*	xesam_g_search_get_session			(XesamGSearch 	*search);

const gchar*	xesam_g_search_get_id				(XesamGSearch 	*search);

guint			xesam_g_search_get_max_batch_size	(XesamGSearch	*search);

void			xesam_g_search_set_max_batch_size	(XesamGSearch	*search,
													 guint			max_size);

const GError*   xesam_g_search_get_last_error	   (XesamGSearch	*search);

G_END_DECLS

#endif /* _XESAM_G_SEARCH_H_ */
