/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
/*
 * xesam-glib
 * Copyright (C) Mikkel Kamstrup Erlandsen 2007 <mikkel.kamstrup@gmail.com>
 * 
 * xesam-glib is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * xesam-glib is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with xesam-glib.  If not, write to:
 * 	The Free Software Foundation, Inc.,
 * 	51 Franklin Street, Fifth Floor
 * 	Boston, MA  02110-1301, USA.
 */


#ifndef __XESAM_G_SEARCHER_H__
#define __XESAM_G_SEARCHER_H__

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>

G_BEGIN_DECLS
#define XESAM_TYPE_G_SEARCHER (xesam_g_searcher_get_type ())
#define XESAM_G_SEARCHER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XESAM_TYPE_G_SEARCHER, XesamGSearcher))
#define XESAM_IS_G_SEARCHER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XESAM_TYPE_G_SEARCHER))
#define XESAM_G_SEARCHER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), XESAM_TYPE_G_SEARCHER, XesamGSearcherIface))

typedef struct _XesamGSearcher XesamGSearcher;
typedef struct _XesamGSearcherIface XesamGSearcherIface;

/* Callback signatures */
typedef void (*XesamGSearcherGotProperty)	(XesamGSearcher	*searcher,
											 gchar			*prop_name,
											 GValue 		*value,
											 gpointer 		user_data,
											 GError			*error);
					   
typedef void (*XesamGSearcherGotHandle) 	(XesamGSearcher	*searcher,
											 gchar			*handle,
											 gpointer		user_data,
											 GError			*error);
					       
typedef void (*XesamGSearcherGotHits)		(XesamGSearcher	*searcher,
											 GPtrArray		*hits,
											 gpointer		user_data,
											 GError			*error);

typedef void (*XesamGSearcherGotHitCount)	(XesamGSearcher	*searcher,
											 guint 			hit_count,
											 gpointer		user_data,
											 GError			*error);
						
typedef void (*XesamGSearcherGotState)		(XesamGSearcher	*searcher,
											 GStrv			state_info,
											 gpointer		user_data,
											 GError			*error);
						
/**
 * XesamGSearcherVoidResponse:
 * @user_data:
 * @error:
 *
 * Callback issued for xesam_g_searcher_close_session(),
 * xesam_g_searcher_close_search() and xesam_g_searcher_start_search()
 *
 * As with all #XesamGSearcher callbacks, the receiver is responsible for
 * freeing all parameters except @searcher, which has not been referenced.
 */
typedef void (*XesamGSearcherVoidResponse)	(XesamGSearcher	*searcher,
											 gpointer		user_data,
											 GError			*error);

/**
 * XesamGSearcherError:
 * @XESAM_G_SEARCHER_ERROR_BAD_RESPONSE: A call to an external source failed
 * 
 * Error codes for #GError<!-- -->s related to #XesamGSearcher<!-- -->s
 */
typedef enum
{
	XESAM_G_SEARCHER_ERROR_BAD_RESPONSE /* Return value from a Searcher is invalid */
} XesamGSearcherError;

struct _XesamGSearcherIface
{
  GTypeInterface parent;
  void (*new_session) (XesamGSearcher * self,
				       XesamGSearcherGotHandle callback,
				       gpointer user_data);
		       
  void (*close_session) (XesamGSearcher	*self,
						 const gchar 	*session_handle,
						 XesamGSearcherVoidResponse callback,
						 gpointer 		user_data);
			 
  void (*get_property) (XesamGSearcher	*self,
  						const gchar		*session_handle,
						const gchar		*prop_name,
						XesamGSearcherGotProperty callback,
						gpointer		user_data);
			
  void (*set_property) (XesamGSearcher	*self,
						const gchar		*session_handle,
						const gchar		*prop_name,
						const GValue	*value,
						XesamGSearcherGotProperty callback,
						gpointer 		user_data);
			
  void (*new_search) (XesamGSearcher	*self,
					  const gchar		*session_handle,
				      const gchar		*query,
				      XesamGSearcherGotHandle callback,
				      gpointer			user_data);
		      
  void (*start_search) (XesamGSearcher	*self,
						const gchar		*search_handle,
						XesamGSearcherVoidResponse callback,
						gpointer		user_data);
			
  void (*close_search) (XesamGSearcher	*self,
						const gchar		*search_handle,
						XesamGSearcherVoidResponse callback,
						gpointer		user_data);
			
  void (*get_hits) (XesamGSearcher		*self,
  				    const gchar			*search_handle,
				    guint 				count,
				    XesamGSearcherGotHits callback,
				    gpointer			user_data);
		    
  void (*get_hit_data) (XesamGSearcher	*self,
  						const gchar		*search_handle,
						GArray			*hit_ids,
						GStrv			field_names,						
						XesamGSearcherGotHits callback,
						gpointer 		user_data);
			
  void (*get_hit_count) (XesamGSearcher	*self,
  						 const gchar	*search_handle,
						 XesamGSearcherGotHitCount callback,
						 gpointer		user_data);
			 
  void (*get_state) (XesamGSearcher		*self,
  				     XesamGSearcherGotState callback,
				     gpointer			user_data);
};


/* Method declarations */

void	xesam_g_searcher_new_session (XesamGSearcher 		*self,
								      XesamGSearcherGotHandle callback,
								      gpointer 				user_data);
				  
void	xesam_g_searcher_close_session	(XesamGSearcher 	*self,
								    	 const gchar 		*session_handle,
								    	 XesamGSearcherVoidResponse	callback,
								    	 gpointer 			user_data);
				    	 
void	xesam_g_searcher_get_property 	(XesamGSearcher		*self,
										 const gchar		*session_handle,
										 const gchar		*prop_name,
										 XesamGSearcherGotProperty	callback,
										 gpointer			user_data);
				   
void	xesam_g_searcher_set_property 	(XesamGSearcher		*self,
										 const gchar 		*session_handle,
										 const gchar 		*prop_name,
										 const GValue		*value,
										 XesamGSearcherGotProperty	callback,
										 gpointer			user_data);
				   
void	xesam_g_searcher_new_search 	(XesamGSearcher 	*self,
										 const gchar		*session_handle,
										 const gchar		*query,
										 XesamGSearcherGotHandle 	callback,
										 gpointer			user_data);
				 
void	xesam_g_searcher_start_search	(XesamGSearcher		*self,
										 const gchar		*search_handle,
										 XesamGSearcherVoidResponse	callback,
										 gpointer			user_data);
				   
void	xesam_g_searcher_close_search 	(XesamGSearcher		*self,
										 const gchar		*search_handle,
										 XesamGSearcherVoidResponse	callback,
										 gpointer			user_data);
				   
void	xesam_g_searcher_get_hits 	(XesamGSearcher 		*self,
									 const gchar			*search_handle,
									 guint					count,
									 XesamGSearcherGotHits	callback,
									 gpointer				user_data);
			    	   
void	xesam_g_searcher_get_hit_data 	(XesamGSearcher 		*self,
										 const gchar			*search_handle,
										 GArray					*hit_ids,
										 GStrv					field_names,										 
										 XesamGSearcherGotHits	callback,
										 gpointer				user_data);
				   
void	xesam_g_searcher_get_hit_count 	(XesamGSearcher 		*self,
										 const gchar			*search_handle,
										 XesamGSearcherGotHitCount	callback,
										 gpointer				user_data);
				    
void	xesam_g_searcher_get_state 	(XesamGSearcher 		*self,
									 XesamGSearcherGotState	callback,
									 gpointer				user_data);

GType	xesam_g_searcher_get_type 	(void);

#define XESAM_G_SEARCHER_ERROR xesam_g_searcher_error_quark()
GQuark	xesam_g_searcher_error_quark (void);

/* Signals */
void	xesam_g_searcher_hits_added		(XesamGSearcher		*self,
										 const gchar		*search_handle,
										 guint				count);

void	xesam_g_searcher_hits_modified	(XesamGSearcher		*self,
										 const gchar		*search_handle,
										 const GArray		*hit_ids);
										 
void	xesam_g_searcher_hits_removed	(XesamGSearcher		*self,
										 const gchar		*search_handle,
										 const GArray		*hit_ids);

void	xesam_g_searcher_search_done	(XesamGSearcher		*self,
										 const gchar		*search_handle);

void	xesam_g_searcher_state_changed	(XesamGSearcher		*self,
										 const GStrv		state_info);

G_END_DECLS
#endif
