/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
/*
 * xesam-glib
 * Copyright (C) Mikkel Kamstrup Erlandsen 2007 <mikkel.kamstrup@gmail.com>
 * 
 * xesam-glib is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * xesam-glib is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with xesam-glib.  If not, write to:
 * 	The Free Software Foundation, Inc.,
 * 	51 Franklin Street, Fifth Floor
 * 	Boston, MA  02110-1301, USA.
 */

#ifndef _XESAM_G_SESSION_H_
#define _XESAM_G_SESSION_H_

#include <glib-object.h>
#include <xesam-glib/xesam-g-query.h>
#include <xesam-glib/xesam-g-searcher.h>

G_BEGIN_DECLS

#define XESAM_TYPE_G_SESSION             (xesam_g_session_get_type ())
#define XESAM_G_SESSION(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), XESAM_TYPE_G_SESSION, XesamGSession))
#define XESAM_G_SESSION_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), XESAM_TYPE_G_SESSION, XesamGSessionClass))
#define XESAM_IS_G_SESSION(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XESAM_TYPE_G_SESSION))
#define XESAM_IS_G_SESSION_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), XESAM_TYPE_G_SESSION))
#define XESAM_G_SESSION_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), XESAM_TYPE_G_SESSION, XesamGSessionClass))

/* Public structs */
typedef struct _XesamGSession XesamGSession;
typedef struct _XesamGSessionClass XesamGSessionClass;

/* Private structs */
typedef struct _XesamGSessionPrivate XesamGSessionPrivate;

/* Forward Declarations */
typedef struct _XesamGSearch XesamGSearch;

struct _XesamGSessionClass
{
	GObjectClass parent_class;
};

struct _XesamGSession
{
	GObject 				parent_instance;
	XesamGSessionPrivate 	*priv;
};


/* Public methods */
GType          	xesam_g_session_get_type 		(void);

XesamGSession* 	xesam_g_session_new 			(XesamGSearcher *searcher);

XesamGSearcher*	xesam_g_session_get_searcher	(XesamGSession 	*session);

gchar*         	xesam_g_session_get_id 			(XesamGSession 	*session);

GHashTable*		xesam_g_session_get_field_map	(XesamGSession 	*session);

gboolean       	xesam_g_session_is_ready 		(XesamGSession 	*session);

gboolean       	xesam_g_session_is_closed 		(XesamGSession 	*session);

void			xesam_g_session_close 			(XesamGSession 	*session);

void 			xesam_g_session_sync_property 	(XesamGSession 	*session,
												 gchar 			*property);

gboolean		xesam_g_session_test_property 	(XesamGSession 	*session,
												 gchar 			*property);

XesamGSearch*	xesam_g_session_new_search 		(XesamGSession 	*session,
												 XesamGQuery 	*query);

XesamGSearch*	xesam_g_session_new_search_from_text
												(XesamGSession 	*session,
												 gchar 			*search_text);

const GError*   xesam_g_session_get_last_error  (XesamGSession  *session);


G_END_DECLS

#endif /* _XESAM_G_SESSION_H_ */
